@@ -20,64 +20,66 @@ use strict;
 use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess);
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 sub ProcessPhotoshop($$$);
 sub WritePhotoshop($$$);
 
 # Photoshop APP13 tag table
+# (set Unknown flag for information we don't want to display normally)
 %Image::ExifTool::Photoshop::Main = (
     GROUPS => { 2 => 'Other' },
     PROCESS_PROC => \&ProcessPhotoshop,
     WRITE_PROC => \&WritePhotoshop,
-#    0x03e8 => 'Photoshop2Info',
-#    0x03e9 => 'MacintoshPrintInfo',
-#    0x03ea => 'XMLData?', #PH
-#    0x03eb => 'Photoshop2ColorTable',
-#    0x03ed => 'ResolutionInfo',
+    0x03e8 => { Unknown => 1, Name => 'Photoshop2Info' },
+    0x03e9 => { Unknown => 1, Name => 'MacintoshPrintInfo' },
+    0x03ea => { Unknown => 1, Name => 'XMLData' }, #PH
+    0x03eb => { Unknown => 1, Name => 'Photoshop2ColorTable' },
+    0x03ed => { Unknown => 1, Name => 'ResolutionInfo' },
     0x03ee => {
         Name => 'AlphaChannelsNames',
         PrintConv => 'Image::ExifTool::Photoshop::ConvertPascalString($val)',
     },
-#    0x03ef => 'DisplayInfo',
-#    0x03f0 => 'PStringCaption',
-#    0x03f1 => 'BorderInformation',
-#    0x03f2 => 'BackgroundColor',
-#    0x03f3 => 'PrintFlags',
-#    0x03f4 => 'BW_HalftoningInfo',
-#    0x03f5 => 'ColorHalftoningInfo',
-#    0x03f6 => 'DuotoneHalftoningInfo',
-#    0x03f7 => 'BW_TransferFunc',
-#    0x03f8 => 'ColorTransferFuncs',
-#    0x03f9 => 'DuotoneTransferFuncs',
-#    0x03fa => 'DuotoneImageInfo',
-#    0x03fb => 'EffectiveBW',
-#    0x03fc => 'ObsoletePhotoshopTag1',
-#    0x03fd => 'EPSOptions',
-#    0x03fe => 'QuickMaskInfo',
-#    0x03ff => 'ObsoletePhotoshopTag2',
-#    0x0400 => 'LayerStateInfo',
-#    0x0401 => 'WorkingPath',
-#    0x0402 => 'LayersGroupInfo',
-#    0x0403 => 'ObsoletePhotoshopTag3',
+    0x03ef => { Unknown => 1, Name => 'DisplayInfo' },
+    0x03f0 => { Unknown => 1, Name => 'PStringCaption' },
+    0x03f1 => { Unknown => 1, Name => 'BorderInformation' },
+    0x03f2 => { Unknown => 1, Name => 'BackgroundColor' },
+    0x03f3 => { Unknown => 1, Name => 'PrintFlags' },
+    0x03f4 => { Unknown => 1, Name => 'BW_HalftoningInfo' },
+    0x03f5 => { Unknown => 1, Name => 'ColorHalftoningInfo' },
+    0x03f6 => { Unknown => 1, Name => 'DuotoneHalftoningInfo' },
+    0x03f7 => { Unknown => 1, Name => 'BW_TransferFunc' },
+    0x03f8 => { Unknown => 1, Name => 'ColorTransferFuncs' },
+    0x03f9 => { Unknown => 1, Name => 'DuotoneTransferFuncs' },
+    0x03fa => { Unknown => 1, Name => 'DuotoneImageInfo' },
+    0x03fb => { Unknown => 1, Name => 'EffectiveBW' },
+    0x03fc => { Unknown => 1, Name => 'ObsoletePhotoshopTag1' },
+    0x03fd => { Unknown => 1, Name => 'EPSOptions' },
+    0x03fe => { Unknown => 1, Name => 'QuickMaskInfo' },
+    0x03ff => { Unknown => 1, Name => 'ObsoletePhotoshopTag2' },
+    0x0400 => { Unknown => 1, Name => 'LayerStateInfo' },
+    0x0401 => { Unknown => 1, Name => 'WorkingPath' },
+    0x0402 => { Unknown => 1, Name => 'LayersGroupInfo' },
+    0x0403 => { Unknown => 1, Name => 'ObsoletePhotoshopTag3' },
     0x0404 => {
         Name => 'IPTCData',
         SubDirectory => {
             TagTable => 'Image::ExifTool::IPTC::Main',
         },
     },
-#    0x0405 => 'RawImageMode',
+    0x0405 => { Unknown => 1, Name => 'RawImageMode' },
     0x0406 => { #2
         Name => 'JPEG_Quality',
         SubDirectory => {
             TagTable => 'Image::ExifTool::Photoshop::JPEG_Quality',
         },
     },
-#    0x0408 => 'GridGuidesInfo',
-#    0x0409 => 'ThumbnailResource',
-#    0x040a => 'CopyrightFlag',
+    0x0408 => { Unknown => 1, Name => 'GridGuidesInfo' },
+    0x0409 => { Unknown => 1, Name => 'ThumbnailResource' },
+    0x040a => { Unknown => 1, Name => 'CopyrightFlag' },
     0x040b => {
         Name => 'URL',
+        Writable => 1,
         Groups => { 2 => 'Author' },
     },
     0x040c => {
@@ -85,26 +87,26 @@ sub WritePhotoshop($$$);
         Groups => { 2 => 'Image' },
         ValueConv => 'my $img=substr($val, 0x1c);\$img',
     },
-#    0x040d => 'GlobalAngle',
-#    0x040e => 'ColorSamplersResource',
-#    0x040f => 'ICC_Profile',
-#    0x0410 => 'Watermark',
-#    0x0411 => 'ICC_Untagged',
-#    0x0412 => 'EffectsVisible',
-#    0x0413 => 'SpotHalftone',
-#    0x0414 => 'IDsBaseValue',
-#    0x0415 => 'UnicodeAlphaNames',
-#    0x0416 => 'IndexedColourTableCount',
-#    0x0417 => 'TransparentIndex',
-#    0x0419 => 'GlobalAltitude',
-#    0x041a => 'Slices',
-#    0x041b => 'WorkflowURL',
-#    0x041c => 'JumpToXPEP',
-#    0x041d => 'AlphaIdentifiers',
-#    0x041e => 'URL_List',
-#    0x0421 => 'VersionInfo',
-#    0x0bb7 => 'ClippingPathName',
-#    0x2710 => 'PrintFlagsInfo',
+    0x040d => { Unknown => 1, Name => 'GlobalAngle' },
+    0x040e => { Unknown => 1, Name => 'ColorSamplersResource' },
+    0x040f => { Unknown => 1, Name => 'ICC_Profile' },
+    0x0410 => { Unknown => 1, Name => 'Watermark' },
+    0x0411 => { Unknown => 1, Name => 'ICC_Untagged' },
+    0x0412 => { Unknown => 1, Name => 'EffectsVisible' },
+    0x0413 => { Unknown => 1, Name => 'SpotHalftone' },
+    0x0414 => { Unknown => 1, Name => 'IDsBaseValue', Description => "ID's Base Value" },
+    0x0415 => { Unknown => 1, Name => 'UnicodeAlphaNames' },
+    0x0416 => { Unknown => 1, Name => 'IndexedColourTableCount' },
+    0x0417 => { Unknown => 1, Name => 'TransparentIndex' },
+    0x0419 => { Unknown => 1, Name => 'GlobalAltitude' },
+    0x041a => { Unknown => 1, Name => 'Slices' },
+    0x041b => { Unknown => 1, Name => 'WorkflowURL' },
+    0x041c => { Unknown => 1, Name => 'JumpToXPEP' },
+    0x041d => { Unknown => 1, Name => 'AlphaIdentifiers' },
+    0x041e => { Unknown => 1, Name => 'URL_List' },
+    0x0421 => { Unknown => 1, Name => 'VersionInfo' },
+    0x0bb7 => { Unknown => 1, Name => 'ClippingPathName' },
+    0x2710 => { Unknown => 1, Name => 'PrintFlagsInfo' },
 );
 
 # Photoshop JPEG quality record (ref 2)
